@@ -235,7 +235,7 @@
   random_parameters <- c("random", "zero_inflated_random", "sigma_random", "beta_random", "car")
 
   # conditional component
-  conditional_component <- setdiff(elements, c(auxiliary_parameters, zero_inflated_component, "smooth_terms"))
+  conditional_component <- setdiff(elements, c(auxiliary_parameters, zero_inflated_component, "smooth_terms", "nonlinear"))
 
   # location parameters
   location_parameters <- switch(effects,
@@ -351,19 +351,19 @@
 
 
 .grep_smoothers <- function(x) {
-  grepl("^(s\\()", x, perl = TRUE) |
-    grepl("^(ti\\()", x, perl = TRUE) |
-    grepl("^(te\\()", x, perl = TRUE) |
-    grepl("^(t2\\()", x, perl = TRUE) |
-    grepl("^(gam::s\\()", x, perl = TRUE) |
-    grepl("^(VGAM::s\\()", x, perl = TRUE) |
-    grepl("^(mgcv::s\\()", x, perl = TRUE) |
-    grepl("^(mgcv::ti\\()", x, perl = TRUE) |
-    grepl("^(mgcv::t2\\()", x, perl = TRUE) |
-    grepl("^(mgcv::te\\()", x, perl = TRUE) |
-    grepl("^(brms::s\\()", x, perl = TRUE) |
-    grepl("^(brms::t2\\()", x, perl = TRUE) |
-    grepl("^(smooth_sd\\[)", x, perl = TRUE)
+  startsWith(x, "s(") |
+  startsWith(x, "ti(") |
+  startsWith(x, "te(") |
+  startsWith(x, "t2(") |
+  startsWith(x, "gam::s(") |
+  startsWith(x, "VGAM::s(") |
+  startsWith(x, "mgcv::s(") |
+  startsWith(x, "mgcv::ti(") |
+  startsWith(x, "mgcv::t2(") |
+  startsWith(x, "mgcv::te(") |
+  startsWith(x, "brms::s(") |
+  startsWith(x, "brms::t2") |
+  startsWith(x, "smooth_sd[")
 }
 
 
