@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight") && require("lme4")) {
+if (requiet("testthat") && requiet("insight") && requiet("lme4")) {
   test_that("find_terms", {
     m <- lm(Sepal.Length ~ -1 + Petal.Width + Species, data = iris)
     expect_equal(
@@ -37,7 +37,7 @@ if (require("testthat") && require("insight") && require("lme4")) {
   dat$time1 <- dat$time - 8
   dat$post <- 0
   dat$post[dat$time >= 8] <- 1
-  m <- lmer(y ~ post + time1 + (post + time1 - 1 | g2), data = dat)
+  m <- suppressMessages(lmer(y ~ post + time1 + (post + time1 - 1 | g2), data = dat))
 
   test_that("find_terms", {
     expect_equal(
