@@ -1,7 +1,7 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
 if (.runThisTest) {
-  if (requiet("testthat") && requiet("insight") && requiet("mgcv")) {
+  if (requiet("testthat") && requiet("insight") && requiet("mgcv") && requiet("httr")) {
     set.seed(123)
     void <- capture.output(
       dat <- mgcv::gamSim(1, n = 400, dist = "normal", scale = 2)
