@@ -2,15 +2,16 @@
 
 if (.runThisTest) {
   unloadNamespace("gam")
-  if (require("testthat") && require("insight") && require("mgcv")) {
+  if (requiet("testthat") && requiet("insight") && requiet("mgcv")) {
     set.seed(0)
-    dat <- gamSim(6, n = 200, scale = .2, dist = "poisson")
+    void <- capture.output(dat <- gamSim(6, n = 200, scale = .2, dist = "poisson"))
     m1 <-
       gamm(
         y ~ s(x0) + s(x1) + s(x2),
         family = poisson,
         data = dat,
-        random = list(fac = ~1)
+        random = list(fac = ~1),
+        verbosePQL = FALSE
       )
 
     test_that("model_info", {
@@ -107,7 +108,7 @@ if (.runThisTest) {
     set.seed(0)
     n.g <- 10
     n <- n.g * 10 * 4
-    dat <- gamSim(1, n = n, scale = 2)
+    void <- capture.output(dat <- gamSim(1, n = n, scale = 2))
     f <- dat$f
     ## simulate nested random effects....
     fa <- as.factor(rep(1:10, rep(4 * n.g, 10)))
@@ -139,12 +140,16 @@ if (.runThisTest) {
     )
 
     set.seed(0)
-    dat <- gamSim(6, n = 200, scale = .2, dist = "poisson")
+
+    void <- capture.output(
+      dat <- gamSim(6, n = 200, scale = .2, dist = "poisson")
+    )
 
     m2 <- gamm(
       y ~ s(x0) + s(x1) + s(x2),
       family = poisson,
-      data = dat
+      data = dat,
+      verbosePQL = FALSE
     )
 
     dat$g <- dat$fac
@@ -152,7 +157,8 @@ if (.runThisTest) {
       y ~ s(x0) + s(x1) + s(x2),
       family = poisson,
       data = dat,
-      random = list(g = ~1)
+      random = list(g = ~1),
+      verbosePQL = FALSE
     )
 
     test_that("find_formula-gamm-1", {
