@@ -143,9 +143,9 @@ if (.runThisTest && .runStanTest) {
           is_gam = FALSE, is_anova = FALSE, is_timeseries = FALSE,
           is_ttest = FALSE, is_correlation = FALSE, is_onewaytest = FALSE,
           is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
-          is_xtab = FALSE, is_proptest = FALSE, is_binomtest = FALSE,
-          is_ftest = FALSE, is_meta = FALSE, link_function = "logit",
-          family = "binomial", n_obs = 56L
+          is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
+          is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE, 
+          link_function = "logit", family = "binomial", n_obs = 56L
         )
       )
 
@@ -164,9 +164,9 @@ if (.runThisTest && .runStanTest) {
           is_gam = FALSE, is_anova = FALSE, is_timeseries = FALSE,
           is_ttest = FALSE, is_correlation = FALSE, is_onewaytest = FALSE,
           is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
-          is_xtab = FALSE, is_proptest = FALSE, is_binomtest = FALSE,
-          is_ftest = FALSE, is_meta = FALSE, link_function = "identity",
-          family = "gaussian", n_obs = 150L
+          is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
+          is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE,
+          link_function = "identity", family = "gaussian", n_obs = 150L
         )
       )
 
@@ -185,9 +185,9 @@ if (.runThisTest && .runStanTest) {
           is_gam = FALSE, is_anova = FALSE, is_timeseries = FALSE,
           is_ttest = FALSE, is_correlation = FALSE, is_onewaytest = FALSE,
           is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
-          is_xtab = FALSE, is_proptest = FALSE, is_binomtest = FALSE,
-          is_ftest = FALSE, is_meta = FALSE, link_function = "logit",
-          family = "binomial", n_obs = 32L
+          is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
+          is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE,
+          link_function = "logit", family = "binomial", n_obs = 32L
         )
       )
 
